#!/bin/sh
#

ACPI="/usr/bin/acpi -b"
IOSTAT="/usr/bin/iostat -c 1 3600"
TOP="/usr/bin/top -b -n 1"

print_date() {
	# The date is printed to the status bar by default.
	# To print the date through this script, set clock_enabled to 0
	# in spectrwm.conf.  Uncomment "print_date" below.
	FORMAT="%a %b %d %R %Z %Y"
	DATE=`date "+${FORMAT}"`
	echo -n "${DATE}     "
}

print_mem() {
	MEM=`${TOP} | grep '^Mem:' | sed 's/[^0-9,k]//g' | cut -d ',' -f 3`
	echo -n "Free mem: $MEM  "
}

_print_cpu() {
	echo -n "CPU: ${1}% User ${2}% Nice ${3}% Sys ${6}% Idle  "
}

print_cpu() {
	OUT=""
	# Remove the decimal part from all the percentages
	while [ "${1}x" != "x" ]; do
		OUT="${OUT} `echo "${1}" | cut -d '.' -f 1`"
		shift;
	done
	_print_cpu $OUT
}

print_acpi() {
	BAT_STATUS="${3}"
	BAT_LEVEL="`echo "${4}" | tr -d ','`"

	case "${BAT_STATUS}" in
	"Charging,")
		FULL="on AC: (battery ${BAT_LEVEL})"
		;;
	"Discharging,")
		FULL="on battery (${BAT_LEVEL})"
		;;
	"")
		FULL="on AC (no battery)"
		;;
	*)
		FULL="(battery unknown)"
		;;
	esac;
	echo -n "${FULL}"
}

while :; do
	# instead of sleeping, use iostat as the update timer.
	# cache the output of acpi(1), no need to call that every second.
	I=0
	${IOSTAT} 2>&1 |
	while read IOSTAT_DATA; do
		if [ ${I} -eq 0 ]; then
			PID="$!"
			trap "kill $PID; exit" TERM
		fi
		if [ $(( ${I} % 10 )) -eq 0 ]; then
			ACPI_DATA=`${ACPI}`
		fi
		if [ $(( ${I} % 3 )) -eq 0 ] && [ ${I} -gt 2 ]; then
			# print_date
			print_mem
			print_cpu $IOSTAT_DATA
			print_acpi $ACPI_DATA
			echo ""
		fi
		I=$(( ${I} + 1 ));
	done
done
